@@ -1,11 +1,13 @@
-#[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
+use serde::Serialize;
+
+#[derive(Serialize, Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
 pub enum LintingError {
-    NonAngularType,
-    EmptyScope,
     NonConventionalCommitsSpecification,
     PrecedingWhitespace,
-    NoSpaceAfterType,
-    NoDescription,
+    NonAngularType,
+    EmptyScope,
+    NoSpaceAfterColonPrecedingTypeAndScope,
+    NoDescriptionAfterTypeAndScope,
 }
 
 pub struct Commit {
